DecodedCallResult typedef
Decoded status and execution facts from a native ABI call.
Implementation
typedef DecodedCallResult = ({int status, ResultFlags flags});
Decoded status and execution facts from a native ABI call.
typedef DecodedCallResult = ({int status, ResultFlags flags});