taiyin_runtime_data_source_flags class sealed
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- TAIYIN_RUNTIME_DATA_SOURCE_BUILTIN → const int
- TAIYIN_RUNTIME_DATA_SOURCE_HAS_COVERAGE → const int
- TAIYIN_RUNTIME_DATA_SOURCE_MEMORY → const int