taiyin_runtime_data_source_format class sealed
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- TAIYIN_RUNTIME_DATA_FORMAT_BUILTIN_EOP → const int
- TAIYIN_RUNTIME_DATA_FORMAT_CUSTOM → const int
- TAIYIN_RUNTIME_DATA_FORMAT_FINALS2000A → const int
- TAIYIN_RUNTIME_DATA_FORMAT_FIXED_STAR → const int
- TAIYIN_RUNTIME_DATA_FORMAT_KEPLER → const int
- TAIYIN_RUNTIME_DATA_FORMAT_MEMORY → const int
- TAIYIN_RUNTIME_DATA_FORMAT_OPM2 → const int
- TAIYIN_RUNTIME_DATA_FORMAT_SEMI_ANALYTIC → const int
- TAIYIN_RUNTIME_DATA_FORMAT_SPK → const int
- TAIYIN_RUNTIME_DATA_FORMAT_TKC1 → const int
- TAIYIN_RUNTIME_DATA_FORMAT_TLL1 → const int
- TAIYIN_RUNTIME_DATA_FORMAT_TSC1 → const int
- TAIYIN_RUNTIME_DATA_FORMAT_UNKNOWN → const int