taiyin_status_code class sealed
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- TAIYIN_EPHEMERIS_ERROR_COMPOSITE_COVERAGE_GAP → const int
- TAIYIN_EPHEMERIS_ERROR_COMPOSITE_METHOD_MISMATCH → const int
- TAIYIN_EPHEMERIS_ERROR_COMPOSITE_MISSING_COMPONENT → const int
- TAIYIN_EPHEMERIS_ERROR_COVERAGE_GAP → const int
- TAIYIN_EPHEMERIS_ERROR_EVAL_FAILED → const int
- TAIYIN_EPHEMERIS_ERROR_LOAD_FAILED → const int
- TAIYIN_EPHEMERIS_ERROR_NO_ROUTE → const int
- TAIYIN_ERROR_INTERNAL → const int
- TAIYIN_ERROR_INVALID_ARGUMENT → const int
- TAIYIN_ERROR_OUT_OF_MEMORY → const int
- TAIYIN_ERROR_UNSUPPORTED → const int
- TAIYIN_EVENT_ERROR_NOT_FOUND → const int
- TAIYIN_FILE_ERROR_BAD_FORMAT → const int
- TAIYIN_FILE_ERROR_DISCOVERY_FAILED → const int
- TAIYIN_FILE_ERROR_NOT_FOUND → const int
- TAIYIN_FILE_ERROR_UNSUPPORTED_FORMAT → const int
- TAIYIN_RUNTIME_ERROR_CACHE_INSERT_FAILED → const int
- TAIYIN_RUNTIME_ERROR_NOT_INITIALIZED → const int
- TAIYIN_RUNTIME_ERROR_REGISTRY_FAILED → const int
- TAIYIN_STATUS_OK → const int
- TAIYIN_TIME_ERROR_EOP_OUT_OF_RANGE → const int
- TAIYIN_TIME_ERROR_LEAP_SECOND_UNAVAILABLE → const int