validateNativeCalendar function
Validates fields that can narrow at the native calendar ABI boundary.
Implementation
void validateNativeCalendar(AstroDateTime value) {
validateNativeInt32(value.year, 'year');
}
Validates fields that can narrow at the native calendar ABI boundary.
void validateNativeCalendar(AstroDateTime value) {
validateNativeInt32(value.year, 'year');
}